/*
 * Copyright 2003 - 2012 The eFaps Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Revision:        $Rev: 7659 $
 * Last Changed:    $Date: 2012-06-13 23:23:03 -0500 (Wed, 13 Jun 2012) $
 * Last Changed By: $Author: jan@moxter.net $
 */

package org.efaps.importer;

import org.apache.commons.digester3.Digester;
import org.apache.commons.digester3.ObjectCreationFactory;
import org.xml.sax.Attributes;

/**
 * <p>Class to create InsertObjects with the Digester using a Constructor with
 * Parameters.</p>
 * <p>This Constructor is needed, because the Attribute "type" is needed from
 * the beginning to store the information about an insert object sorted by the
 * type. This information can't be changed later.</p>
 *
 * @author The eFaps Team
 * @version $Id: InsertObjectBuilder.java 7659 2012-06-14 04:23:03Z jan@moxter.net $
 */
public class InsertObjectBuilder
    implements ObjectCreationFactory<InsertObject>
{
    /**
     * Returns a new instance of the insert object for given type defined in
     * <code>_attributes</code>.
     *
     * @param _attributes   attributes used to get the type for the insert
     *                      object
     * @return new insert object instance
     */
    public InsertObject createObject(final Attributes _attributes)
    {
        return new InsertObject(_attributes.getValue("type"));
    }

    /**
     * The digester is not needed from the insert object factory and therefore
     * this method is only a stub.
     *
     * @return always <code>null</code>
     */
    public Digester getDigester()
    {
        return null;
    }

    /**
     * The digester is not needed from the insert object factory and therefore
     * this method is only a stub.
     *
     * @param _digester     not used
     */
    public void setDigester(final Digester _digester)
    {
    }
}
